@@ -2,13 +2,15 @@
 """GNUmed person searching code.
 
 	How-To search:
-		name:		Leonard Spock "Pointy-Ears" NIMOY-ZALDANA
-		DOB:		Oct 15 1975
-		ID:			12345678
-		ext ID:		abcd-13d-4d
-		ext ID:		#abcd-13d-4d
 
-	find patient by name (first, last, nick):
+		name:     Leonard Spock "Pointy-Ears" NIMOY-ZALDANA
+		DOB:      Oct 15 1975
+		ID:       12345678
+		ext ID:   abcd-13d-4d
+		ext ID:   #abcd-13d-4d
+
+	find patient by name (first, last, or nick):
+
 		'leon'
 		'spo'
 		'nimo'
@@ -16,24 +18,29 @@
 		'pointy'
 
 	find patient by lastname:
+
 		'NIMO'
 		'ZALD'
 		'nIm,'
 		'Zal,'
 
 	find patient by firstname:
+
 		', spo'
 		',Leon'
 
 	find patient by nickname:
+
 		'!point'
 		'!ear'
 
 	find patient by firstname and lastname:
+
 		'Leonard NIMO'
 		'spock ZALDA'
 
 	find patient by fragment anywhere inside name:
+
 		'...ock'
 		'...ldan'
 		'...moY'
@@ -41,15 +48,19 @@
 		'...Ear'
 
 	find patient by several name parts:
+
 		'leon nim'
 		'spo zal'
 		'leon nim zald'
+		'kirk, jam'
 
 	find patient by GNUmed ID:
+
 		'12345678' (also searches by DOB)
 		'#12345678' (also searches by external ID)
 
 	find patient by DOB:
+
 		'15101975' (also searches for GNUmed ID)
 		'*15101975'
 		'*15/10/1975'
@@ -58,6 +69,7 @@
 		'*15 10 1975'
 
 	find patient by external ID:
+
 		'##abcd-13d-4d'		(finds ID "abcd-13d-4d")
 		'## #abcd-13d-4d'	(finds ID "#abcd-13d-4d")
 """
@@ -66,13 +78,18 @@ __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
 # std lib
-import sys, logging, re as regex
+import sys
+import logging
+import re as regex
 
 
 # GNUmed
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
-from Gnumed.pycommon import gmPG2, gmI18N, gmTools, gmDateTime
+from Gnumed.pycommon import gmPG2
+from Gnumed.pycommon import gmI18N
+from Gnumed.pycommon import gmTools
+from Gnumed.pycommon import gmDateTime
 from Gnumed.business import gmPerson
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
