@@ -78,15 +78,15 @@ if __name__ == "__main__":
 	gmDateTime.init()
 
 	patfile = sys.argv[1]
-	print "reading patient data from PATIENTS.IN PracSoft file [%s]" % patfile
+	print("reading patient data from PATIENTS.IN PracSoft file [%s]" % patfile)
 
 	dtos = read_persons_from_pracsoft_file(patfile)
 	for dto in dtos:
-		print "DTO:", dto
-		print "dto.dob:", dto.dob, type(dto.dob)
-		print "dto.dob.tz:", dto.dob.tzinfo
-		print "dto.zip: %s dto.urb: %s" % (dto.zip, dto.urb)
-		print "dto.street", dto.street
+		print("DTO:", dto)
+		print("dto.dob:", dto.dob, type(dto.dob))
+		print("dto.dob.tz:", dto.dob.tzinfo)
+		print("dto.zip: %s dto.urb: %s" % (dto.zip, dto.urb))
+		print("dto.street", dto.street)
 #		searcher = gmPersonSearch.cPatientSearcher_SQL()
 #		ident = searcher.get_identities(dto=dto)[0]
 #		print ident
