@@ -8,6 +8,7 @@ import sys
 import os.path
 import io
 import logging
+import datetime as pydt
 
 
 # 3rd party
@@ -541,10 +542,9 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 			return
 
 		self.SetItemHasChildren(episode_node, True)
-
 		for enc in encounters:
 			label = '%s: %s' % (
-				enc['started'].strftime('%Y-%m-%d'),
+				enc['started'].strftime('%Y %b %d'),
 				gmTools.unwrap (
 					gmTools.coalesce (
 						gmTools.coalesce (
@@ -684,9 +684,17 @@ class cEMRTree(wx.TreeCtrl, treemixin.ExpansionState):
 			return
 
 		for enc_item in encounter_items:
-			item_node = self.AppendItem(encounter_node, '%s [%s] %s' % (
-				enc_item['clin_when'].strftime('%H:%M'),
+			if encounter['started'].year != enc_item['clin_when'].year:
+				when = enc_item['clin_when'].strftime('%Y')
+			elif encounter['started'].month != enc_item['clin_when'].month:
+				when = enc_item['clin_when'].strftime('%b')
+			elif encounter['started'].day != enc_item['clin_when'].day:
+				when = enc_item['clin_when'].strftime('%b %d')
+			else:
+				when = enc_item['clin_when'].strftime('%H:%M')
+			item_node = self.AppendItem(encounter_node, '[%s] %s: %s' % (
 				enc_item.i18n_soap_cat,
+				when,
 				enc_item.item_type_str
 			))
 			self.SetItemData(item_node, enc_item)
