@@ -413,7 +413,7 @@ class cFileDropTarget(wx.FileDropTarget):
 		self._on_drop_callback(filenames)
 
 # ========================================================================
-def file2scaled_image(filename=None, height=100):
+def file2scaled_image(filename:str=None, height:int=100):
 	img_data = None
 	bitmap = None
 	rescaled_height = height
@@ -421,11 +421,7 @@ def file2scaled_image(filename=None, height=100):
 		img_data = wx.Image(filename, wx.BITMAP_TYPE_ANY)
 		current_width = img_data.GetWidth()
 		current_height = img_data.GetHeight()
-#		if current_width == 0:
-#			current_width = 1
-#		if current_height == 0:
-#			current_height = 1
-		rescaled_width = (float(current_width) / current_height) * rescaled_height
+		rescaled_width = round(current_width / current_height) * rescaled_height
 		img_data.Rescale(rescaled_width, rescaled_height, quality = wx.IMAGE_QUALITY_HIGH)		# w, h
 		bitmap = wx.Bitmap(img_data)
 		del img_data
@@ -434,6 +430,7 @@ def file2scaled_image(filename=None, height=100):
 		del img_data
 		del bitmap
 		return None
+
 	return bitmap
 
 # ========================================================================
